aboutsummaryrefslogtreecommitdiffstats
path: root/capture.c
diff options
context:
space:
mode:
authorguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2003-12-18 19:07:14 +0000
committerguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2003-12-18 19:07:14 +0000
commite0b7af3932a9329e425b70591f89cdcb167f0e2d (patch)
tree609bd927b0dcbece1639f340a78fe2d058e1fa1d /capture.c
parent3cd5c2fa8a9c442c13f99ba6866dbcd90dca60b2 (diff)
From Jan Kiszka: IrDA support.
git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@9345 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'capture.c')
-rw-r--r--capture.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/capture.c b/capture.c
index 21b41e9205..64b20a33a6 100644
--- a/capture.c
+++ b/capture.c
@@ -1,7 +1,7 @@
/* capture.c
* Routines for packet capture windows
*
- * $Id: capture.c,v 1.217 2003/11/17 19:40:09 guy Exp $
+ * $Id: capture.c,v 1.218 2003/12/18 18:56:36 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -1593,8 +1593,8 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
#endif
}
- /* capture filters only work on real interfaces */
- if (cfile.cfilter && !ld.from_pipe) {
+ /* capture filters only work on real interfaces, except IrDA adapters */
+ if (cfile.cfilter && !ld.from_pipe && strncmp(cfile.iface, "irda", 4) != 0) {
/* A capture filter was specified; set it up. */
if (pcap_lookupnet(cfile.iface, &netnum, &netmask, lookup_net_err_str) < 0) {
/*